@@ -1,17 +1,22 @@
-from .apns_config import ApnsConfig
+from .apns_config import ApnsConfig, LiveActivityApnsConfig, VoIPApnsConfig
 from .apns_priority import ApnsPriority
 from .apns_push_type import ApnsPushType
 from .critical_sound import CriticalSound
 from .interruption_level import InterruptionLevel
-from .payload import Payload
+from .live_activity_event import LiveActivityEvent
+from .payload import LiveActivityPayload, Payload
 from .payload_alert import PayloadAlert
 
 __all__ = [
     "ApnsConfig",
+    "LiveActivityApnsConfig",
+    "VoIPApnsConfig",
     "ApnsPriority",
     "ApnsPushType",
     "CriticalSound",
     "InterruptionLevel",
+    "LiveActivityEvent",
     "Payload",
+    "LiveActivityPayload",
     "PayloadAlert",
 ]
